Module crypto_classifier

Module crypto_classifier 

Crypto classification heuristics โ€” single source of truth.

Used by both Symbol::is_crypto() and Ticker::FromStr to determine whether a trading pair is a cryptocurrency pair.

Functions

is_crypto_base
Check if base symbol is a known cryptocurrency.
is_crypto_quote
Check if quote currency is a crypto quote (stablecoins, BTC, ETH, etc.).